.google-submit {
    float: left;
    width: 100%;
    padding-top: 1em;
    text-align: center;
}

.social-block {
    display:inline-block;
    text-align: center;
    padding:1em;
    background-color:#E8E8EC;
    border-radius:10px;
}

.social-logo {
    width: 4em;
    vertical-align: middle;
    padding-right: 1em;
}
